Struct PushPromises
struct PushPromises { ... }
A stream of pushed responses and corresponding promised requests
Implementations
impl PushPromises
async fn push_promise(self: &mut Self) -> Option<Result<PushPromise, Error>>Get the next
PushPromise.
impl Debug for PushPromises
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for PushPromises
impl RefUnwindSafe for PushPromises
impl Send for PushPromises
impl Sync for PushPromises
impl Unpin for PushPromises
impl UnsafeUnpin for PushPromises
impl UnwindSafe for PushPromises
impl<T> Any for PushPromises
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for PushPromises
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for PushPromises
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for PushPromises
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Instrument for PushPromises
impl<T> WithSubscriber for PushPromises
impl<T, U> Into for PushPromises
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for PushPromises
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for PushPromises
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>