Setting

Enum Setting 

pub enum Setting {
    HeaderTableSize(u32),
    EnablePush(u32),
    MaxConcurrentStreams(u32),
    InitialWindowSize(u32),
    MaxFrameSize(u32),
    MaxHeaderListSize(u32),
    EnableConnectProtocol(u32),
    NoRfc7540Priorities(u32),
}
An enum that lists all valid settings that can be sent in a SETTINGS frame.

Each setting has a value that is a 32 bit unsigned integer (6.5.1.).

Variants



HeaderTableSize(u32)



EnablePush(u32)



MaxConcurrentStreams(u32)



InitialWindowSize(u32)



MaxFrameSize(u32)



MaxHeaderListSize(u32)



EnableConnectProtocol(u32)



NoRfc7540Priorities(u32)

Implementations

Source

impl Setting

pub fn id(&self) -> u16

Returns the setting ID for this setting.

pub fn from_id(id: u16, val: u32) -> Option<Setting>

Creates a new Setting with the correct variant corresponding to the given setting id, based on the settings IDs defined in section 6.5.2.