Struct Ping

struct Ping { ... }

Sent via PingPong to send a PING frame to a peer.

Implementations

impl Ping

fn opaque() -> Ping

Creates a new opaque Ping to be sent via a PingPong.

The payload is "opaque", such that it shouldn't be depended on.

impl Debug for Ping

fn fmt(self: &Self, fmt: &mut Formatter<'_>) -> Result

impl Freeze for Ping

impl RefUnwindSafe for Ping

impl Send for Ping

impl Sync for Ping

impl Unpin for Ping

impl UnsafeUnpin for Ping

impl UnwindSafe for Ping

impl<T> Any for Ping

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Ping

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Ping

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Ping

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for Ping

impl<T> WithSubscriber for Ping

impl<T, U> Into for Ping

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Ping

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Ping

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>