Struct PingPong

struct PingPong { ... }

A handle to send and receive PING frames with the peer.

Implementations

impl PingPong

async fn ping(self: &mut Self, ping: Ping) -> Result<Pong, Error>

Send a PING frame and wait for the peer to send the pong.

impl Debug for PingPong

fn fmt(self: &Self, fmt: &mut Formatter<'_>) -> Result

impl Freeze for PingPong

impl RefUnwindSafe for PingPong

impl Send for PingPong

impl Sync for PingPong

impl Unpin for PingPong

impl UnsafeUnpin for PingPong

impl UnwindSafe for PingPong

impl<T> Any for PingPong

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for PingPong

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for PingPong

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for PingPong

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for PingPong

impl<T> WithSubscriber for PingPong

impl<T, U> Into for PingPong

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for PingPong

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for PingPong

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>