Struct PushedResponseFuture

struct PushedResponseFuture { ... }

A future of a pushed HTTP response.

We have to differentiate between pushed and non pushed because of the spec https://httpwg.org/specs/rfc7540.html#PUSH_PROMISE

PUSH_PROMISE frames MUST only be sent on a peer-initiated stream that is in either the "open" or "half-closed (remote)" state.

Implementations

impl PushedResponseFuture

fn stream_id(self: &Self) -> StreamId

Returns the stream ID of the response stream.

Panics

If the lock on the stream store has been poisoned.

impl Debug for PushedResponseFuture

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for PushedResponseFuture

impl Future for PushedResponseFuture

fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<<Self as >::Output>

impl RefUnwindSafe for PushedResponseFuture

impl Send for PushedResponseFuture

impl Sync for PushedResponseFuture

impl Unpin for PushedResponseFuture

impl UnsafeUnpin for PushedResponseFuture

impl UnwindSafe for PushedResponseFuture

impl<F> IntoFuture for PushedResponseFuture

fn into_future(self: Self) -> <F as IntoFuture>::IntoFuture

impl<F, T, E> TryFuture for PushedResponseFuture

fn try_poll(self: Pin<&mut F>, cx: &mut Context<'_>) -> Poll<<F as Future>::Output>

impl<T> Any for PushedResponseFuture

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for PushedResponseFuture

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for PushedResponseFuture

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for PushedResponseFuture

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for PushedResponseFuture

impl<T> WithSubscriber for PushedResponseFuture

impl<T, U> Into for PushedResponseFuture

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for PushedResponseFuture

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for PushedResponseFuture

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>