Function handshake
fn handshake<T>(io: T) -> Handshake<T, Bytes>
where
T: AsyncRead + AsyncWrite + Unpin
Creates a new configured HTTP/2 server with default configuration
values backed by io.
It is expected that io already be in an appropriate state to commence
the HTTP/2 handshake. See Handshake for more details.
Returns a future which resolves to the Connection instance once the
HTTP/2 handshake has been completed. The returned Connection
instance will be using default configuration values. Use Builder to
customize the configuration values used by a Connection instance.
Examples
# use ;
# use server;
# use *;
#
# async #
#
#