Struct Error
struct Error { ... }
Represents HTTP/2 operation errors.
Error covers error cases raised by protocol errors caused by the
peer, I/O (transport) errors, and errors caused by the user of the library.
If the error was caused by the remote peer, then it will contain a
Reason which can be obtained with the reason function.
Implementations
impl Error
fn reason(self: &Self) -> Option<Reason>If the error was caused by the remote peer, the error reason.
This is either an error received by the peer or caused by an invalid action taken by the peer (i.e. a protocol error).
fn is_io(self: &Self) -> boolReturns true if the error is an io::Error
fn get_io(self: &Self) -> Option<&Error>Returns the error if the error is an io::Error
fn into_io(self: Self) -> Option<Error>Returns the error if the error is an io::Error
fn is_go_away(self: &Self) -> boolReturns true if the error is from a
GOAWAY.fn is_reset(self: &Self) -> boolReturns true if the error is from a
RST_STREAM.fn is_remote(self: &Self) -> boolReturns true if the error was received in a frame from the remote.
Such as from a received
RST_STREAMorGOAWAYframe.fn is_library(self: &Self) -> boolReturns true if the error was created by
h2.Such as noticing some protocol error and sending a GOAWAY or RST_STREAM.
impl Debug for Error
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for Error
fn fmt(self: &Self, fmt: &mut Formatter<'_>) -> Result
impl Error for Error
impl Freeze for Error
impl From for Error
fn from(src: Reason) -> Error
impl RefUnwindSafe for Error
impl Send for Error
impl Sync for Error
impl Unpin for Error
impl UnsafeUnpin for Error
impl UnwindSafe for Error
impl<T> Any for Error
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Error
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Error
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Error
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Instrument for Error
impl<T> ToString for Error
fn to_string(self: &Self) -> String
impl<T> WithSubscriber for Error
impl<T, U> Into for Error
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Error
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Error
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>